from dataclasses import dataclass
import numpy
import numpy.typing


@dataclass
class StaticDipole():
	'''
	Representation of a static dipoles, either known or guessed.

	Parameters
	----------
	p : numpy.ndarray
		The static dipole moment.
	s : numpy.ndarray
		The position of the dipole.
	'''
	p: numpy.ndarray
	s: numpy.ndarray

	def __post_init__(self) -> None:
		'''
			Coerce the inputs into numpy arrays.
		'''
		self.p = numpy.array(self.p)
		self.s = numpy.array(self.s)

	def v_at_position(self, r: numpy.typing.ArrayLike) -> float:

		diff = r - self.s
		return self.p.dot(diff) / (numpy.linalg.norm(diff)**3)
